<?php
/**
 * Customizer Control Classes files.
 *
 * @package RT_Portfolio
 */

if ( ! class_exists( 'WP_Customize_Control' ) )
  return NULL;

/**
 * Class RT_Portfolio_Dropdown_Taxonomies_Control
 */
class RT_Portfolio_Dropdown_Taxonomies_Control extends WP_Customize_Control {

    /**
     * Render the control's content.
     *
     * @since 3.4.0
     */
    public function render_content() {
        $dropdown = wp_dropdown_categories(
            array(
                'name'              => 'rt-portfolio-dropdown-categories-' . $this->id,
                'echo'              => 0,
                'show_option_none'  => __( '&mdash; Select &mdash;', 'rt-portfolio' ),
                'option_none_value' => '0',
                'selected'          => $this->value(),
                'hide_empty'        => 0,                   

            )
        ); 
        
        $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );

        printf(
            '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s <span class="description customize-control-description"></span>%s </label>',
            esc_html($this->label),
            esc_html($this->description),
            $dropdown

        );
    }

}
/**
 * Upsell customizer section.
 *
 * @since  1.0.0
 * @access public
 */
class rt_portfolio_Customize_Section_Upsell extends WP_Customize_Section {
    /**
    * The type of customize section being rendered.
    *
    * @since  1.0.0
    * @access public
    * @var    string
    */
    public $type = 'upsell';

    /**
    * Custom button text to output.
    *
    * @since  1.0.0
    * @access public
    * @var    string
    */
    public $pro_text = '';

    /**
    * Custom pro button URL.
    *
    * @since  1.0.0
    * @access public
    * @var    string
    */
    public $pro_url = '';

    /**
    * Add custom parameters to pass to the JS via JSON.
    *
    * @since  1.0.0
    * @access public
    * @return void
    */
    public function json() {
    $json = parent::json();

    $json['pro_text'] = $this->pro_text;
    $json['pro_url']  = esc_url( $this->pro_url );

    return $json;
    }

    /**
    * Outputs the Underscore.js template.
    *
    * @since  1.0.0
    * @access public
    * @return void
    */
    protected function render_template() { ?>

        <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">

            <h3 class="accordion-section-title">
                {{ data.title }}

                <# if ( data.pro_text && data.pro_url ) { #>
                    <a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
                <# } #>

            </h3>
        </li>
    <?php }
}
